macro_rules! submit_hook {
($name:ident, $point:expr, $tag_filter:expr, $order:expr, $handler:ident,) => { ... };
}Expand description
Convenience macro for submitting hook registrations from proc macro expansion.
macro_rules! submit_hook {
($name:ident, $point:expr, $tag_filter:expr, $order:expr, $handler:ident,) => { ... };
}Convenience macro for submitting hook registrations from proc macro expansion.